MacRumors Forums - Mac News and Rumor Discussion
Description: Mac News and Rumors Discussion Forums
Keywords: apple, mac rumors

Got a tip for us? Let us know

User Name |  | Remember Me?
Password |  |

Welcome to the MacRumors Forums.
If this is your first visit, be sure to check out our FAQs. You will have to register before you can post: click the register link above to proceed. To start viewing messages, select the forum that you want to visit from the selection below.

| Forum | Last Post | Threads | Posts
News and Article Discussion
| MacRumors.com News Discussion front page news and rumors | Eddy Cue Speaks on Apple's... by HiRez Today 05:18 PM | 12,032 | 2,332,207
| Mac Blog Discussion Mac news, software, tips, and gear | Steve Wozniak Discusses... by EightBitJoe Today 04:57 PM | 2,840 | 184,175
| iOS Blog Discussion iPhone, iPad and iPod touch news, software, tips, and gear | Spotify Promotion Offers... by DanGoh Today 05:09 PM | 3,592 | 167,638
iPhone, iPod and iPad
| iOS iOS 8 iOS 7 iOS 6 iOS 5 and earlier Jailbreaks and iOS Hacks | HDR on my iPhone 5s looks... by azhava Today 05:16 PM | 77,777 | 832,323
| iPhone general discussion iPhone Tips, Help and Troubleshooting iPhone Accessories iPhone Launch Meetups iPhone Wallpapers etc. | Carrier: Anyone Tempted by Sprint 1/2... by jksu Today 05:18 PM | 197,096 | 2,719,300
| iPad general discussion (use iPad Apps forum for app discussions) iPad Tips, Help and Troubleshooting iPad Accessories iPad Launch Meetups iPad Wallpapers etc. iPad Apps | iPad: Boxwave clear case by LevMac Today 05:16 PM | 51,695 | 803,602
| iPod touch general discussion iPod touch Accessories | All I want is a 128GB iPod... by RoboWarriorSr Today 03:53 PM | 22,082 | 186,794
| iPod | First 3 Songs My iPod Played... by MeeMac Today 05:13 PM | 20,314 | 146,111
| Apple Watch Apple Watch discussions | Where is it going to be sold by Mascots Today 05:15 PM | 459 | 8,420
| Alternatives to iOS and iOS Devices Discussion of non-Apple smartphones, tablets, and watches; their operating systems; comparisons with Apple products | Affordable way to test... by DeathTheKid Today 05:18 PM | 5,167 | 183,648
Apple Applications Apple and third-party software (software developers: see Guidelines for Software Developers)
| iPhone and iPod touch Apps App Store: 3rd party apps for iPhone and iPod touch | [Free][Game] DIAMOND BIRD by scfxv Today 04:41 PM | 29,001 | 178,350
| iPad Apps App Store: 3rd party apps for iPad | Beware: Fraudulent... by Jessica Lares Today 03:31 PM | 8,664 | 50,232
| Mac Applications and Mac App Store Software for Macs, apps in the Mac App Store | Can't install software in... by scottyb70 Today 04:19 PM | 101,815 | 555,396
Apple Hardware
| Desktops iMac Mac Pro Mac mini | Fix to prevent the 280X from... by Earl Urley Today 05:13 PM | 80,316 | 1,047,575
| Notebooks MacBook MacBook Pro MacBook Air | Windows 8.1 EFI on new Retina... by saturnotaku Today 05:19 PM | 158,135 | 1,806,701
| PowerPC Macs PPC Macs: Power Mac, PowerBook, iMac Gx, iBook, G4 Cube, eMac, etc. | 'Bad Apples' craiglist thread. by weckart Today 04:18 PM | 18,656 | 173,480
| Apple TV and Home Theater Apple's TV-iTunes bridge and other home theater discussion | NAS vs. External Set-up by priitv8 Today 04:41 PM | 18,406 | 172,715
| Mac Peripherals displays, keyboards, mice, printers, speakers, etc... | Show us your... by GreenApple29 Today 05:09 PM | 35,002 | 217,634
| Buying Tips and Advice what to buy, when to buy, talk about purchases, get pricing advice (but no offers to buy/sell/trade) | When should I buy my MacBook? by BenTrovato Today 04:54 PM | 44,729 | 457,683
Apple Systems and Services
| Mac Basics and Help new to mac or not sure where to post? ask any hardware or software question here. | cannot send message using the... by kershawh Today 04:21 PM | 68,282 | 373,604
| OS X OS X Yosemite (10.10) OS X Mavericks (10.9) OS X 10.8 Mountain Lion Mac OS X 10.7 Lion Mac OS X Server, Xserve, and Networking | Force delete stuck files by Sangoma Today 05:13 PM | 93,385 | 672,197
| iCloud and Apple Services Apple's online services | Apple vs Chromebook by oliviergoulet Today 04:54 PM | 8,727 | 48,860
| Windows, Linux & Others on the Mac Boot Camp and Windows discussion | Windows 10 free... by saturnotaku Today 05:06 PM | 20,168 | 119,090
| Programming iPhone/iPad Programming Mac Programming App Store Business, Legal and Marketıng | Mapping framework that allows... by Dookieman Today 05:16 PM | 31,297 | 180,778
Special Interests
| Mac and PC Games computer-based games (use separate subforum for console games) Console Games | OS-neutral: GoG Winter Sale Begins by xSinghx Today 03:59 PM | 13,788 | 172,248
| Digital Audio audio-oriented apps and techniques | Nice looking, high quality... by Tucom Yesterday 11:41 PM | 6,319 | 37,306
| Visual Media Design and Graphics Digital Photography Digital Video Web Design and Development | Preferred website for photo... by jjk454ss Today 04:45 PM | 43,471 | 450,493
| Apple Collectors older and collectable Apple products: 680x0 Macs, Apple II, Newton, System 7, etc. | Quadra 700 by DZ/015 Today 08:13 AM | 2,192 | 23,985
| Distributed Computing seti, folding, etc... | New FAH'er by ChristianJapan Today 02:17 AM | 966 | 18,163
Mac Community
| Community Discussion anything else that interests you Apple, Industry and Internet Discussion Current Events Politics, Religion, Social Issues | Ferguson on edge by Eraserhead Today 05:12 PM | 60,880 | 1,819,525
| Picture Gallery post photos, pictures, videos, etc... UI Customization | Who's got a nice watch? by ipodlover77 Today 05:11 PM | 4,127 | 386,295
| Site and Forum Feedback questions, suggestions, & comments about the site or forums; MacRumors announcements Mac Guides | Migrating to Xenforo by Partron22 Today 05:07 PM | 5,261 | 82,076
Private Forums $25/year contribution removes most ads and provides access to private forums: details here
Archive older posts
| Wasteland trash posts | Why is the iPhone 6 round by lordofthereef Nov 30, 2014 10:56 PM | 11,049 | 213,971
| Archives of Old Posts | A gave me his iPhone 4S... by RenoG Sep 20, 2012 11:28 AM | 123,303 | 1,662,347
Mark Forums Read

What's Going On?
MacRumors Forums Statistics
| Threads: 1,703,869, Posts: 19,682,149, Members: 936,210 Welcome to our newest member, Liulai
Today's Birthdays
| prostuff1, Grayburn (38)

| Forum Contains New Posts
| Forum Contains No New Posts

All times are GMT -5. The time now is 05:20 PM.
Mac Rumors | Mac | iPhone | iPhone Game Reviews | iPhone Apps

Contact Us - MacRumors Forums - Archive - Privacy Statement / DMCA Agent - Top

Mobile Version | Fixed | Fluid | Fluid HD
Privacy / DMCA contact / Affiliate and FTC Disclosure
Copyright 2002-2013, MacRumors.com, LLC